@@ -1,8 +1,8 @@
 import json
 import re
 import socket
-import time
 from http import HTTPStatus
+from typing import Union
 from urllib.parse import urljoin, urlencode
 
 import requests
@@ -90,22 +90,7 @@ class RESTClient(RESTAssertion):
         self.auth_uri = auth_uri
         self.auth_payload = auth_payload
         self.auth_basic = auth_basic
-
-        # Default header
-        self.header = header or get_header_default()
-
-        # Create auth header
-        if self.auth_payload:
-            try:
-                self.token = AuthToken(self).token
-                self.header['Authorization'] = self.token
-            except KeyError as err:
-                logger.error(f'Cannot get token. {err}')
-
-        # Set basic Authorization if enabled
-        elif self.auth_basic:
-            self.auth_basic = (self.username, self.password)
-            self.header = {}
+        self.header = header or get_header_default()  # Default header
 
     def __str__(self):
 
@@ -132,6 +117,21 @@ class RESTClient(RESTAssertion):
     def _validate_url(url):
         return re.match(r'http[s]?://[\w/.]+', url)
 
+    def _auth_payload(self):
+        """Get auth token if enabled"""
+
+        try:
+            self.token = AuthToken(self).token
+            self.header['Authorization'] = self.token
+        except KeyError as err:
+            logger.error(f'Cannot get token. {err}')
+
+    def _auth_basic(self):
+        """Enable basic auth if provided"""
+
+        self.header = {}
+        return self.username, self.password
+
     def send_request(self,
                      method: str,
                      url: str,
@@ -164,6 +164,16 @@ class RESTClient(RESTAssertion):
 
         """
 
+        # Set auth method
+        if self.auth_payload is not None:
+            try:
+                self.token = AuthToken(self).token
+                self.header['Authorization'] = self.token
+            except KeyError as err:
+                logger.error(f'Cannot get token. {err}')
+        elif self.auth_basic:
+            self.auth_basic = self._auth_basic()
+
         # Make full url to use in request
         link = self._requested_url(url)
 
@@ -244,7 +254,6 @@ class RESTClient(RESTAssertion):
 
             # For 'GET', 'HEAD' request
             else:
-
                 # For usual 'GET' without query params
                 header = custom_header if custom_header is not None else self.header
 
@@ -269,7 +278,7 @@ class RESTClient(RESTAssertion):
 
     @property
     def is_service_available(self):
-        """Check base url availability within 30 sec."""
+        """Check base url availability within 10 sec."""
 
         try:
             response = requests.get(self.base_url, timeout=10, verify=False)
@@ -377,7 +386,7 @@ class RESTClient(RESTAssertion):
             result = sock.connect_ex((self.host, port_))
             return False if result else True
 
-    def is_service_initialized(self, timeout: int = 20) -> bool:
+    def is_service_initialized(self, timeout: Union[int, float] = 20) -> bool:
         """GET https://{IP}:{PORT}
 
         :param timeout:
@@ -404,10 +413,8 @@ class RESTClient(RESTAssertion):
             status = self.is_service_initialized(1)
             timer += 1
 
-            if timer > timeout:
-                print(f'The service was not started within {timeout} seconds.')
-                raise TimeoutError
-            time.sleep(1)
+            if timer > timeout - 2:
+                raise TimeoutError(f'The service was not started within {timeout} seconds.')
         return status
 
 
