@@ -4,7 +4,7 @@ import logging
 logger_name = 'RESTClient'
 logger = logging.getLogger(logger_name)
 logger.setLevel(logging.INFO)
-formatter = logging.Formatter(fmt='%(asctime)-15s | %(levelname)s | %(name)s | %(message)s',
+formatter = logging.Formatter(fmt='%(asctime)-15s | %(levelname)s | %(name)s:%(lineno)d | %(message)s',
                               datefmt='%Y-%m-%d %H:%M:%S')
 
 # Console logger
